# pyjeasy
[![Python: 3.6](https://img.shields.io/badge/Python-3.6-blue.svg)](#)
[![Build Status](https://travis-ci.org/GeorgiosGoniotakis/python-hierarchy.svg?branch=master)](https://github.com/Jitesh17/pyjeasy)
[![license: MIT](https://img.shields.io/badge/license-MIT-orange.svg)](https://opensource.org/licenses/MIT)

Useful python tools



## Installation
### Method 1: Pip install

```python
pip install pyjeasy
```

### Method 2

```python
pip install https://github.com/jitesh17/pyjeasy/archive/master.zip
```

### Method 3: Git clone

```python
git clone https://github.com/jitesh17/pyjeasy.git
cd pyjeasy
pip install -e .
```

